#  prosody

Python Prosody API: Emotion & Prosody sensitive TTS

## How To Use
### Installing

Install prosody using pip
```
python -m pip install prosody
```

### Examples

From `prosody_api` package import `Client` class, then create a Client object with your valid username and password.
```
from prosody.prosody_api import Client

cli = Client('your_id', 'your_password')
```

## Authors

* **Suwon Shin** - *Initial work* - [shh1574](https://github.com/shh1574)
* **Yuneui Jeong** - *From 0.0.3* - [laviande22](https://github.com/laviande22)
